pari_galpol: PARI data package for polynomials defining Galois extensions of the rationals
==========================================================================================

Description
-----------

PARI package of the GALPOL database of polynomials defining Galois
extensions of the rationals, accessed by galoisgetpol, galoisgetgroup,
galoisgetname.

License
-------

GNU General Public License (GPL version 2 or any later version).


Upstream Contact
----------------

http://pari.math.u-bordeaux.fr/

Dependencies
------------

-  Installation: None
-  Runtime: PARI/GP
